@@ -8,7 +8,7 @@ configure and implement a workflow to operate on a signac_ data space.
 
 .. _signac: https://signac.io/
 """
-from . import environment, errors, hooks, scheduling, testing
+from . import environment, environments, errors, hooks, scheduling, testing
 from .aggregates import aggregator, get_aggregate_id
 from .environment import get_environment
 from .operations import cmd, directives, with_job
@@ -16,13 +16,12 @@ from .project import FlowProject, IgnoreConditions, classlabel, label, staticlab
 from .template import init
 
 # Import packaged environments unless disabled in config:
-from .util.config import _FLOW_CONFIG_DEFAULTS
-from .util.config import get_config_value as _get_config_value
 from .util.misc import redirect_log
 from .version import __version__
 
 __all__ = [
     "environment",
+    "environments",
     "errors",
     "hooks",
     "scheduling",
@@ -42,12 +41,3 @@ __all__ = [
     "redirect_log",
     "__version__",
 ]
-
-
-if _get_config_value(
-    "import_packaged_environments",
-    default=_FLOW_CONFIG_DEFAULTS["import_packaged_environments"],
-):
-    from . import environments  # noqa: F401
-
-    __all__.append("environments")
